import path from 'path';
import process from 'process';
import { defineConfig, loadEnv } from 'vite';
import vue from '@vitejs/plugin-vue';
import AutoImport from 'unplugin-auto-import/vite';
import Components from 'unplugin-vue-components/vite';
import { ElementPlusResolver, ArcoResolver, VantResolver } from 'unplugin-vue-components/resolvers';
import { visualizer } from 'rollup-plugin-visualizer';
import vueI18n from '@intlify/vite-plugin-vue-i18n';
import { cliDir, appDir, srcDir } from './config.js';
import { chunkSplitPlugin } from 'vite-plugin-chunk-split';

// TODO: 完成图标使用方案

export default defineConfig(({ command, mode }) => {
    return {
        plugins: [
            //
            vue({
                reactivityTransform: true
            }),
            AutoImport({
                include: [/\.[tj]sx?$/, /\.vue$/, /\.vue\?vue/, /\.md$/],
                imports: ['vue'],
                dirs: [
                    //
                    path.resolve(srcDir, 'components'),
                    path.resolve(srcDir, 'plugins')
                ],
                vueTemplate: true,
                dts: '.yicode/auto-imports.d.ts',
                resolvers: [ElementPlusResolver(), ArcoResolver()]
            }),
            Components({
                directoryAsNamespace: true,
                resolvers: [
                    //
                    ElementPlusResolver(),
                    ArcoResolver({
                        sideEffect: true
                    }),
                    VantResolver()
                ]
            }),
            vueI18n({
                include: path.resolve(srcDir, 'i18n/**')
            }),
            chunkSplitPlugin({
                strategy: 'default',
                customSplitting: {
                    'vue-vendor': ['vue', 'vue-router']
                }
            }),
            visualizer({
                open: false,
                brotliSize: true,
                filename: '.cache/buildReport.html'
            })
        ],
        css: {
            preprocessorOptions: {
                scss: {
                    additionalData: `@use "@/styles/variable.scss" as *;`
                }
            }
        },
        resolve: {
            alias: [
                {
                    find: '@',
                    replacement: path.resolve(srcDir)
                }
            ]
        },
        root: appDir,
        base: './',
        envDir: path.resolve(srcDir, 'env'),
        build: {
            rollupOptions: {
                plugins: []
            }
        },
        server: {
            port: 8000,
            hmr: {
                protocol: 'ws',
                host: 'localhost'
            }
        }
    };
});
